/*
  STM32F030 oscillators status using direct register access and HAL
*/

uint32_t  i,j;

RCC_OscInitTypeDef  RCC_struct;  // Needed for HAL_RCC_GetOscConfig function

void setup() {

  Serial.begin(9600);

  i = (RCC->CFGR & RCC_CFGR_SWS) >> 2;      // Clock configuration register (RCC_CFGR) - SWS
  j = (RCC->CFGR & RCC_CFGR_PLLSRC) >> 16;  // Clock configuration register (RCC_CFGR) - PLLSRC
  
  Serial.println("\n* STM32F030 Oscillators Configuration *");

  Serial.print("System Clock Switch status (RCC_CFGR_SWS): ");
  Serial.print(i);
  switch (i)
  {
    case 0: Serial.print(" (HSI selected)"); break;
    case 1: Serial.print(" (HSE selected)"); break;
    case 2: Serial.print(" (PLL selected)"); break;
  }
  Serial.println();

  Serial.print("PLL source (RCC_CFGR_PLLSRC): ");
  Serial.print(j);
  switch (j)
  {
    case 0: Serial.print(" (HSI/2)"); break;
    case 1: Serial.print(" (HSE)"); break;
  }
  Serial.println();

  HAL_RCC_GetOscConfig(&RCC_struct);
  Serial.println("* Status from HAL_RCC_GetOscConfig *");
  Serial.print("HSE status: ");
  Serial.println(RCC_struct.HSEState);
  
  Serial.print("HSI status: ");
  Serial.println(RCC_struct.HSIState);

  Serial.print("LSE status: ");
  Serial.println(RCC_struct.LSEState);

  Serial.print("LSI status: ");
  Serial.println(RCC_struct.LSIState);
    
  pinMode(LED_BUILTIN, OUTPUT);
}

void loop() {
  digitalWrite(LED_BUILTIN, HIGH);   // turn the LED on (HIGH is the voltage level)
  delay(1000);                       // wait for a second
  digitalWrite(LED_BUILTIN, LOW);    // turn the LED off by making the voltage LOW
  delay(1000);                       // wait for a second
}
